Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var ErrProxyHealthDisconnect = errors.New("proxy health disconnect")
ErrProxyHealthDisconnect is a sentinel error returned when the proxy exits due to a health-check-triggered disconnection. It should be suppressed from stderr in main.go since the ssh client will report the disconnect naturally.
Functions ¶
func NewRootCmd ¶
Types ¶
Click to show internal directories.
Click to hide internal directories.